<?php
/**
 * MythEvent is an abstract class encapsulating a recording monitor.
 *
 * @version $Id: MythEvent.php,v 1.7 2006/03/16 06:27:55 dbattams Exp $
 * @author Derek Battams <derek@battams.ca>
 * @package MRE
 * @copyright 2006 GPL v2
 */

/**#@+
 * Required include
 */
require_once(APP_ROOT . '/class/SysConf.php');
/**#@-*/

/**
 * Abstract class encapsulating a recording monitor
 *
 * Concrete subclasses of MythEvent are objects that somehow monitor the
 * status of an event and determine if the event is over or still in
 * progress.  MythEvents are then attached to active MythTV recordings and
 * based on the status of the event, the recording is either extended,
 * reduced or left alone based on the status of the event and the time
 * remaining in the recording.
 *
 * @package MRE
 */
abstract class MythEvent
{
   /**
    * @var string Status of the event as scanned by the monitor
    */
   private $_status;

   /**
    * @var bool Flag denoting if the event being monitored is over or not
    */
   private $_isOver;

   /**
    * @var bool Was the monitor able to find and parse the data about the event?
    */
   private $_isValid;

   /**#@+
    * Class getters and setters
    */
   public function isValid()
   {
      return $this->_isValid;
   }

   /**
    * Set the validity flag the given value
    *
    * @param bool Boolean value
    */
   protected function setValid($bool)
   {
      $this->_isValid = (bool) $bool;
      return;
   }

   /**
    * Return the event status
    *
    * @return string The status of the event
    */
   public function getStatus()
   {
      return $this->_status;
   }

   /**
    * Returns a boolean indicating if the event is over
    *
    * @return bool
    */
   public function isEventOver()
   {
      return $this->_isOver;
   }

   /**
    * Set the event's status
    *
    * @param string The event's status message
    */
   protected function setStatus($str)
   {
      $this->_status = $str;
      return;
   }

   /**
    * Set the event's isOver flag
    *
    * @param bool
    */
   protected function setEventOver($bool)
   {
      $this->_isOver = $bool;
      return;
   }
   /**#@-*/

   /**
    * Class constructor.
    */
   public function __construct()
   {
      $this->_isValid = FALSE;
      return;
   }

   /**
    * Given a string, deduce a list of key words.
    *
    * Typically, this method will be called with the subtitle of a recording
    * and that subtitle will be broken down into an array of key words that
    * can be used to search some external data source for information about
    * the event being described in the subtitle.  Common, vague and small
    * words are removed from the argument and the remaining words are returned
    * as an array.
    *
    * @param string A string to deduce key words from
    * @return array An array of key words deduced from the argument
    */
   public function generateSearchTerms($str)
   {
      $config = SysConf::getInstance();
      $criteria = array();

      $datFile = APP_ROOT . '/data/' . get_class($this) . '.dat';
      if(file_exists($datFile))
      {
         $terms = file($datFile);
         foreach($terms as $t)
         {
            $t = trim($t);
            if(preg_match('/' . preg_quote($t) . '/', $str))
               $criteria[] = $t;
         }
      }
      else
      {
         $list = explode(' ', $str);
         foreach($list as $i)
            if(strlen($i) > 3)
               $criteria[] = $i;
      }
      if($config->getOpt('verbose') >= SysConf::DEBUG)
         var_dump($criteria);
      return $criteria;
   }
}

?>
