<?php
/**
 * RecordingFactory gathers and returns requested Recording objects.
 *
 * Though not a factory as per the common design pattern, I still call it
 * a factory for lack of a better word.  RecordingFactory's various methods
 * return a specific subset of MythTV's recordings.
 *
 * @version $Id: RecordingFactory.php,v 1.8 2006/08/14 00:17:59 dbattams Exp $
 * @author Derek Battams <derek@battams.ca>
 * @package MRE
 * @copyright 2006 GPL v2
 */

/**#@+
 * Required include
 */
require_once(APP_ROOT . '/class/Recording.php');
require_once(APP_ROOT . '/class/InvalidCache.php');
require_once(APP_ROOT . '/class/SysConf.php');
/**#@-*/

/**
 * Each method filters the MythTV recordings and returns an array of objects.
 *
 * Each method filters the MythTV recordings and returns an array of
 * Recording objects representing the filter as specified in the method called.
 *
 * @package MRE
 */
class RecordingFactory
{
   /**
    * Return an array consisting of Recording objects that are due to end soon.
    *
    * Return an array of Recordings objects that are due to end in the next 30
    * minutes.
    * @return array Array of Recording objects due to end soon.
    */ 
   static public function getNearEndingRecordings()
   {
      $qry = "SELECT * FROM recorded
              WHERE
              endtime > NOW() AND recordid <> 0 AND recgroup <> 'LiveTV' AND
                  DATE_ADD(NOW(), INTERVAL 30 MINUTE) >= endtime";
      $invalids = InvalidCache::getCache();
      if(sizeof($invalids))
      {
         $qry .= ' AND (';
         foreach($invalids as $i)
            $extras[] = "(chanid <> $i[0] AND starttime <> '$i[1]')";
         $qry .= implode(' OR ', $extras);
         $qry .= ')';
      }
      return self::getMythRecordings($qry);
   }

   /**
    * Return an array of Recording objects that have just started to record.
    *
    * Return an array of Recording objects that have just started to record in
    * the last 3 sleep intervals (default would be 15 minutes).
    * @return array An array of Recording objects that have just started.
    */
   static public function getNewlyStartedRecordings()
   {
      $interval = SysConf::getInstance()->getOpt('sleep') * 3;
      $qry = "SELECT * FROM recorded
	      WHERE
	      endtime > NOW() AND recordid <> 0 AND recgroup <> 'LiveTV' AND
		  DATE_ADD(starttime, INTERVAL $interval MINUTE) >= NOW()";
      return self::getMythRecordings($qry);
   }

   /**
    * Returns an array of MythTV recordings filtered by the argument, which is
    * a valid SQL query.
    *
    * Returns an array of Recording objects that represents all MythTV
    * recordings that are filtered by the SQL query specified in the argument. 
    *
    * @return array An array of Recording objects.
    */
   static protected function getMythRecordings($qry)
   {
      $config = SysConf::getInstance();
      $db = $config->getDB();

      if(DB::isError($res=$db->setFetchMode(DB_FETCHMODE_OBJECT, 'Recording')))
      {
         if($config->verbose >= SysConf::DEBUG)
            echo $res->getDebugInfo();
         else if($config->verbose >= SysConf::ERROR)
            echo $res->getMessage();
         trigger_error('Unable to set fetch mode!', E_USER_ERROR);
      }
      $recs = array();
      $res = $db->query($qry);
      if(!DB::isError($res))
      {
         while(!DB::isError($obj = $res->fetchRow()) && $obj)
            $recs[] = $obj;
         if(DB::isError($obj))
         {
            if($config->verbose >= SysConf::DEBUG)
               echo $obj->getDebugInfo();
            else if($config->verbose >= SysConf::ERROR)
               echo $obj->getMessage();
            trigger_error("Processing result set failed!", E_USER_ERROR);
         }
         $res->free();
      }
      else
      {
         if($config->getOpt('verbose') >= SysConf::DEBUG)
            echo $res->getDebugInfo();
         else if($config->getOpt('verbose') >= SysConf::WARNING)
            echo $res->getMessage();
         trigger_error("Database query failed!", E_USER_WARNING);
      }
      return $recs;
   }
}

?>
